@@ -33,14 +33,14 @@ class Decoupage(object):
                  'template_directories': '' # list of directories to look for templates
                  }
 
-    def __init__(self, **app_conf):
+    def __init__(self, **kw):
 
         # set defaults from app configuration
-        kw = self.app_conf('decoupage', app_conf)
         for key in self.defaults:
             setattr(self, key, kw.get(key, self.defaults[key]))
 
         # configure defaults
+        assert self.directory, "Decoupage: directory not specified"
         self.auto_reload = self.auto_reload.lower() == 'true'
         self.cascade = self.cascade.lower() == 'true'
         self.directory = self.directory.rstrip(os.path.sep)
@@ -54,8 +54,8 @@ class Decoupage(object):
         self.fileserver = FileApp
 
         # pluggable formats
-        s = 'decoupage.format.'
-        _format_args = [ (i.split(s, 1)[-1], j) for i, j in app_conf.items()
+        s = 'format.'
+        _format_args = [ (i.split(s, 1)[-1], j) for i, j in kw.items()
                          if i.startswith(s) ]
         format_args = {}
         for i, j in _format_args:
@@ -96,19 +96,27 @@ class Decoupage(object):
         
 
     ### methods dealing with HTTP
+        
     def __call__(self, environ, start_response):
+
+        # boilerplate: request and filename
         request = Request(environ)
         filename = request.path_info.strip('/')
         path = os.path.join(self.directory, filename)
+
+        # check to see what we have to serve
         if os.path.exists(path):
+            
             if os.path.isdir(path):
-
-                if not request.path_info.endswith('/'):
-                    raise exc.HTTPMovedPermanently(add_slash=True)
-
-                res = self.get(request)
+                # serve an index
+                if request.path_info.endswith('/'):
+                    res = self.get(request)
+                else:
+                    res = exc.HTTPMovedPermanently(add_slash=True)
                 return res(environ, start_response)
+
             else:
+                # serve a file
                 conf = self.conf(request.path_info.rsplit('/',1)[0])
                 if '/transformer' in conf:
                     args = [i.split('=', 1) for i in conf['/transformer'].split(',') if '=' in i]
@@ -125,7 +133,9 @@ class Decoupage(object):
                 fileserver = fileserver(path)
                 return fileserver(environ, start_response)
         else:
-            raise exc.HTTPNotFound()
+            # file does not exist
+            response = exc.HTTPNotFound()
+            return response(environ, start_response)
 
 
     def get(self, request):
@@ -146,6 +156,9 @@ class Decoupage(object):
         files = self.filedata(path, directory, conf)
         data = {'path': path, 'files': files, 'request': request }
 
+        # add a function to get the path to files
+        data['filepath'] = lambda *segments: os.path.join(*([directory] + list(segments)))
+
         # defaults; TODO: make this better
         # there shouldn't need to be defaults;
         # iirc, genshi has a mode where these will default to None
@@ -198,8 +211,8 @@ class Decoupage(object):
                 if os.path.exists(_template):
                     template = _template
                 else:
-                    for directory in self.template_directories:
-                        if template in os.listdir(directory):
+                    for _directory in self.template_directories:
+                        if template in os.listdir(_directory):
                             break
                     else:
                         raise IOError("template %s not found" % template)
@@ -309,9 +322,3 @@ class Decoupage(object):
                 if key in self.formatters:
                     formatter = self.formatters[key](value)        
 
-
-    def app_conf(self, keystr, app_conf):
-        keystr += '.'
-        return dict([(key.split(keystr, 1)[-1], value)
-                     for key, value in app_conf.items()
-                     if key.startswith(keystr) ])        
